@@ -1,16 +1,13 @@
 import os
 
-from conan.api.output import ConanOutput
 from conan.internal.cache.cache import PkgCache
 from conan.internal.cache.home_paths import HomePaths
 from conans.client.graph.proxy import ConanProxy
 from conans.client.graph.python_requires import PyRequireLoader
 from conans.client.graph.range_resolver import RangeResolver
-from conans.client.hook_manager import HookManager
 from conans.client.loader import ConanFileLoader, load_python_file
 from conans.client.remote_manager import RemoteManager
 from conans.client.rest.auth_manager import ConanApiAuthManager
-from conans.client.rest.conan_requester import ConanRequester
 from conan.internal.api.remotes.localdb import LocalDB
 
 
@@ -37,38 +34,38 @@ class ConanFileHelpers:
         self.home_folder = home_folder
 
 
-class ConanApp:
+class ConanBasicApp:
     def __init__(self, conan_api):
+        """ Needs:
+        - Global configuration
+        - Cache home folder
+        """
         global_conf = conan_api.config.global_conf
+        self.global_conf = global_conf
         cache_folder = conan_api.home_folder
-        self._configure(global_conf)
         self.cache_folder = cache_folder
         self.cache = PkgCache(self.cache_folder, global_conf)
-
-        home_paths = HomePaths(self.cache_folder)
-        self.hook_manager = HookManager(home_paths.hooks_path)
-
-        # Wraps an http_requester to inject proxies, certs, etc
-        self.requester = ConanRequester(global_conf, cache_folder)
-        # To handle remote connections
         # Wraps RestApiClient to add authentication support (same interface)
-        self.localdb = LocalDB(cache_folder)
-        auth_manager = ConanApiAuthManager(self.requester, cache_folder, self.localdb, global_conf)
+        localdb = LocalDB(cache_folder)
+        auth_manager = ConanApiAuthManager(conan_api.remotes.requester, cache_folder, localdb, global_conf)
         # Handle remote connections
         self.remote_manager = RemoteManager(self.cache, auth_manager, cache_folder)
+        global_editables = conan_api.local.editable_packages
+        ws_editables = conan_api.workspace.editable_packages
+        self.editable_packages = global_editables.update_copy(ws_editables)
 
-        self.proxy = ConanProxy(self, conan_api.local.editable_packages)
-        self.range_resolver = RangeResolver(self, global_conf, conan_api.local.editable_packages)
 
-        self.pyreq_loader = PyRequireLoader(self, global_conf)
-        cmd_wrap = CmdWrapper(home_paths.wrapper_path)
-        conanfile_helpers = ConanFileHelpers(self.requester, cmd_wrap, global_conf, self.cache,
-                                             self.cache_folder)
+class ConanApp(ConanBasicApp):
+    def __init__(self, conan_api):
+        """ Needs:
+        - LocalAPI to read editable packages
+        """
+        super().__init__(conan_api)
+        self.proxy = ConanProxy(self, self.editable_packages)
+        self.range_resolver = RangeResolver(self, self.global_conf, self.editable_packages)
+
+        self.pyreq_loader = PyRequireLoader(self, self.global_conf)
+        cmd_wrap = CmdWrapper(HomePaths(self.cache_folder).wrapper_path)
+        conanfile_helpers = ConanFileHelpers(conan_api.remotes.requester, cmd_wrap, self.global_conf,
+                                             self.cache, self.cache_folder)
         self.loader = ConanFileLoader(self.pyreq_loader, conanfile_helpers)
-
-    @staticmethod
-    def _configure(global_conf):
-        ConanOutput.set_warnings_as_errors(global_conf.get("core:warnings_as_errors",
-                                                           default=[], check_type=list))
-        ConanOutput.define_silence_warnings(global_conf.get("core:skip_warnings",
-                                                            default=[], check_type=list))
